#-----------------------------------------------------------------------
# File    : chull.mak
# Contents: commands to build convex hull construction program
# Author  : Christian Borgelt
# History : 29.01.2003 file created
#           20.07.2006 adapted to Visual Studio 8
#-----------------------------------------------------------------------
THISDIR = ..\..\chull\src
UTILDIR = ..\..\util\src
DRAWDIR = ..\..\draw\src

CC      = cl.exe
DEFS    = /D WIN32 /D NDEBUG /D WINDOWS /D _CRT_SECURE_NO_WARNINGS
CFLAGS  = /nologo /W3 /O2 /GS- $(DEFS) /c
INC     = /I $(UTILDIR) /I $(DRAWDIR)

RSC     = rc.exe
RFLAGS  = /l 0x407 /d NDEBUG

LD      = link.exe
LDFLAGS = /nologo /incremental:no
LIBS    = user32.lib comdlg32.lib gdi32.lib

HDRS    = $(UTILDIR)\lists.h    $(UTILDIR)\random.h \
          $(DRAWDIR)\proj3d.h   chull.h
OBJS    = $(UTILDIR)\lists.obj  $(UTILDIR)\random.obj \
          $(DRAWDIR)\proj3d.obj chull.obj
PRGS    = wchull.exe chtime.exe sphere.exe

#-----------------------------------------------------------------------
# Build Programs
#-----------------------------------------------------------------------
all:        $(PRGS)

wchull.exe: $(OBJS) wchull.obj wchull.res chull.mak
	$(LD) $(LDFLAGS) $(OBJS) wchull.obj wchull.res $(LIBS) \
        /subsystem:windows /out:$@

chtime.exe: $(OBJS) chtime.obj chull.mak
	$(LD) $(LDFLAGS) $(OBJS) chtime.obj $(LIBS) \
        /subsystem:console /out:$@

sphere.exe: sphere.obj chull.mak
	$(LD) $(LDFLAGS) sphere.obj $(LIBS) \
        /subsystem:console /out:$@

#-----------------------------------------------------------------------
# Main Programs
#-----------------------------------------------------------------------
wchull.obj: $(HDRS) wchull.c chull.mak
	$(CC) $(CFLAGS) $(INC) /D _WINDOWS wchull.c /Fo$@

chtime.obj: $(HDRS) chtime.c chull.mak
	$(CC) $(CFLAGS) $(INC) /D _CONSOLE chtime.c /Fo$@

sphere.obj: sphere.c chull.mak
	$(CC) $(CFLAGS) /D _CONSOLE sphere.c /Fo$@

#-----------------------------------------------------------------------
# Convex Hull Module
#-----------------------------------------------------------------------
chull.obj:  $(HDRS) chull.h chull.c chull.mak
	$(CC) $(CFLAGS) $(INC) /D CH_DRAW chull.c /Fo$@

#-----------------------------------------------------------------------
# Resources
#-----------------------------------------------------------------------
wchull.res:  wchull.rh wchull.rc chull.mak
	$(RSC) $(RFLAGS) /fo$@ wchull.rc

#-----------------------------------------------------------------------
# External Modules
#-----------------------------------------------------------------------
$(UTILDIR)\lists.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak lists.obj
	cd $(THISDIR)
$(UTILDIR)\random.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak random.obj
	cd $(THISDIR)
$(DRAWDIR)\proj3d.obj:
	cd $(DRAWDIR)
	$(MAKE) /f draw.mak proj3d.obj
	cd $(THISDIR)

#-----------------------------------------------------------------------
# Install
#-----------------------------------------------------------------------
install:
	-@copy *.exe ..\..\..\bin

#-----------------------------------------------------------------------
# Clean up
#-----------------------------------------------------------------------
clean:
	$(MAKE) /f chull.mak localclean
	cd $(UTILDIR)
	$(MAKE) /f util.mak clean
	cd $(DRAWDIR)
	$(MAKE) /f draw.mak clean
	cd $(THISDIR)

localclean:
	-@erase /Q *~ *.obj *.idb *.pch *.res $(PRGS)
